pub enum WorktreeFileContent {
Text(String),
Missing,
Binary,
TooLarge,
}Expand description
Bounded content returned when reading a worktree file for presentation.
Variants
Text(String)
The file contains valid UTF-8 text within the preview byte limit.
Missing
The file does not exist in the current worktree.
Binary
The file is not valid UTF-8 text.
TooLarge
The file exceeds the preview byte limit.