branch_tracking_statuses

Function branch_tracking_statuses 

pub async fn branch_tracking_statuses(
    repo_path: PathBuf,
) -> Result<BranchTrackingMap, GitError>
Re-exported commit/sync/diff APIs. Returns ahead/behind snapshots for every local branch in repo_path.

The returned map is keyed by local branch name. Branches without an upstream, with a gone upstream, or without ahead/behind markers map to None.

Errors

Returns a GitError if git for-each-ref fails.