commit_all

Function commit_all 

pub async fn commit_all(
    repo_path: PathBuf,
    commit_message: String,
    no_verify: bool,
) -> Result<(), GitError>
Re-exported commit/sync/diff APIs. Stages all changes and commits them with the given message.

Arguments

  • repo_path - Path to the git repository or worktree
  • commit_message - Message for the commit
  • no_verify - When true, skips configured git hooks such as prek-managed pre-commit and commit-msg hooks (--no-verify)

Returns

Ok(()) on success.

Errors

Returns a GitError if staging or committing changes fails.